div.resmng_nav {
    float: left;
    width: 250px;
}
div.resmng_nav .tab-content{
    overflow: visible;
}
.resmng_content{
    float: left;
    padding-left: 50px;
    width: 850px;
}
.form-actions-top {
    padding: 5px 0;
}
.resmng_tree_menu > .sub-menu{
	height: 600px;
	overflow-y: auto;
}